# Micorservices Base

## Description

A set of simple utility classes for d4k microservices.

## Installation

```bash
pip install d4k-ms-base
```

## Building package

Use pip to install build and twine. Use the following commands to build

```python3 -m build --sdist --wheel``` 

and upload to pypi.org using the command

```twine upload dist/*``` 
